
//-----------------------------------------------------------------------------
#include <c8051f320.h>                  // SFR declarations
#include <intrins.h>

#define gfx1_Page_base 0xB0
#define gfx1_Col_base_h 0x10
#define gfx1_Col_base_l 0x00

sbit CS1 = P0^6;						//CS1 pin of GFX
sbit RES = P0^5;						//Reset pin of GFX
sbit A0P = P0^4;						//A0P pin of GFX
// sbit SD  = P0^1;                      // Master Out / Slave In (output)
// sbit SCL = P0^3;                       // Serial Clock (output)
//-----------------------------------------------------------------------------
// Function PROTOTYPES
//-----------------------------------------------------------------------------

void SYSCLK_Init (void);
void PORT_Init (void);
void SPISend (unsigned char SPI_byte);
void LCD_Init(void);
void SPI_Init (void);
void gfx1_data (unsigned char data2);
void gfx1_command (unsigned char data1);

//-----------------------------------------------------------------------------
// MAIN Routine
//-----------------------------------------------------------------------------

void main (void)
{
	unsigned char l;

	PCA0MD &= ~0x40;            // WDTE = 0 (clear watchdog timer)                                          // enable)
	SYSCLK_Init ();             // Initialize system clock to 24.5MHz
	PORT_Init ();               // Initialize crossbar and GPIO
	SPI_Init ();				// Initialise SPIO
	LCD_Init();					// Initialise LCD

	for(l=0; l<128; l++)		// write pattern 01010101 to page0 
	{
		gfx1_data (0x55);
	}

	while(1)
	{
			 					// Add program here
	}
}


//-----------------------------------------------------------------------------
// SYSCLK_Init
//-----------------------------------------------------------------------------
//
// This routine initializes the system clock to use the internal 24.0MHz / 2
// oscillator as its clock source.

void SYSCLK_Init (void)
{
	OSCICN = 0x82;              // configure internal oscillator for 12 Mhz
}

//-----------------------------------------------------------------------------
// PORT_Init
//-----------------------------------------------------------------------------
//
// Configure the Crossbar and GPIO ports.

void PORT_Init (void)
{
   XBR0     = 0x02;                       // Digital peripherals SPIO selected
   XBR1     = 0x40;                       // Enable crossbar & weak pull-ups enabled
   P0MDIN  |= 0x77;                       // Enable SPIO SCK & MOSI + RES/CS1/AOP as a digital output
   P0MDOUT |= 0x77;                       // Enable SPIO SCK & MOSI + RES/CS1/AOP as push-pull output
}

//-----------------------------------------------------------------------------
// SPI_Init
//-----------------------------------------------------------------------------
//
// Configure the SPIO Bus.  3-wire Master Mode, data centered on second edge of SCK period
// and SCK line high in idle state.

void SPI_Init (void)
{
   SPI0CFG	= 0x70;
   SPIEN = 1;
}

//-----------------------------------------------------------------------------
// SPISend Fonction
//-----------------------------------------------------------------------------
//
// Convert byte into SPI format data

void SPISend (unsigned char SPI_byte)
{
	SPIF = 0;    
	SPI0DAT = SPI_byte;
	while (!SPIF);
}	
//	unsigned char i;
//        for(i=7; i>=0; i--)
//        {
//            if ((SPI_byte>>i)&0x01)
//            {
//                SD = 1;
//            }
//            else
//            {
//                SD = 0;
//            }
//            SCL = 0;
//            SCL = 1;
//        }	


//-----------------------------------------------------------------------------
// gfx1_command Function
//-----------------------------------------------------------------------------
//
// Write commands i.e. page and column addresses
 
void gfx1_command (unsigned char data1 )
{
    A0P = 0;
    SPISend (data1);
}

//-----------------------------------------------------------------------------
// gfx1_command Function
//-----------------------------------------------------------------------------
//
// Write display data

void gfx1_data (unsigned char data2 )
{
    A0P = 1;
    SPISend (data2);
}

//------------------------------------------------------------------------------
// Init_LCD
//------------------------------------------------------------------------------
//
// Initialisation.  6.xx refers to the section of the Sunplus SPLC501C datasheet

void LCD_Init (void)
{
	CS1 = 0;
	RES = 0;						// Reset is 0.5us
	_nop_ ();
	RES = 1;
	gfx1_command(0xA2);				// LCD Bias Setting - 6.11
	gfx1_command(0xA0);				// Normal Display Mode - 6.10
	gfx1_command(0xC8);				// Common Output Mode - 6.15
	gfx1_command(0x23);				// V5 Voltage Reg Internal Resistor - 6.17
	gfx1_command(0x81);				// Electronic Volume Double Command - 6.18
	gfx1_command(0x0A);				// adjust for correcr contrast
	gfx1_command(0x2B);				// Power Control Circuit - 6.16
	gfx1_command(0x40);				// Display Start Line Set - 6.2
	gfx1_command(gfx1_Page_base);	// Page Adress Set - 6.3
	gfx1_command(gfx1_Col_base_h);	// Column Adress Set High bits - 6.4
	gfx1_command(gfx1_Col_base_l);	// Column Adress Set Low bits - 6.4
	gfx1_command(0xAF);				// Display ON - 6.1
}
